@@ -161,6 +161,10 @@ class PaymentTransaction(Workflow, ModelSQL, ModelView):
         ('posted', 'Posted'),
         ('cancel', 'Canceled'),
     ], 'State', readonly=True)
+    shipping_address = fields.Function(
+        fields.Many2One('party.address', 'Shipping Address'),
+        'get_shipping_address'
+    )
 
     def get_rec_name(self, name=None):
         """
@@ -323,7 +327,7 @@ class PaymentTransaction(Workflow, ModelSQL, ModelView):
             res['address.rec_name'] = self.payment_profile.address.rec_name
         return res
 
-    def get_provider(self):
+    def get_provider(self, name=None):
         """
         Return the gateway provider based on the gateway
         """
@@ -342,6 +346,7 @@ class PaymentTransaction(Workflow, ModelSQL, ModelView):
                 'provider': self.gateway.provider,
                 'method': self.gateway.method,
             }
+        return {}
 
     def on_change_with_provider(self):
         return self.get_provider()
@@ -554,6 +559,15 @@ class PaymentTransaction(Workflow, ModelSQL, ModelView):
     def use_card(cls, transactions):
         pass
 
+    def get_shipping_address(self, name):
+        """
+        Returns the shipping address for the transaction.
+
+        The downstream modules can override this to send the
+        appropriate address in transaction.
+        """
+        return None
+
 
 class TransactionLog(ModelSQL, ModelView):
     "Transaction Log"
